# Consensus Clustering

![PyPI](https://img.shields.io/pypi/v/consensusclustering)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/consensusclustering)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/consensusclustering)
![PyPI - License](https://img.shields.io/pypi/l/consensusclustering)
![Codecov](https://img.shields.io/codecov/c/github/burtonrj/consensusclustering)
![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/burtonrj/consensusclustering/build.yaml)

## Description

`consensusclustering` is a python implementation of the Consensus Clustering
algorithm for finding the optimal number of clusters by means of clustering
stability under resampling, as originally proposed by [Monti et al. Consensus
Clustering: A Resampling-Based Method for Class Discovery and Visualization of Gene
Expression Microarray Data (2003)](https://link.springer.com/article/10.1023/A:1023949509487).

## Installation

`consensusclustering` can be installed from PyPi using pip:

```bash
pip install consensusclustering
```

## Usage

See the 'examples' directory for a detailed overview of the package's functionality.

## License

Cytotransform is licensed under the MIT license, is free to use, and comes with no warranty whatsoever.
